@@ -15,8 +15,8 @@ from aioetherscan.network import Network
 
 class Client:
     def __init__(self, api_key: str, api_kind: str = 'eth', network: str = 'main',
-                 loop: AbstractEventLoop = None, timeout: ClientTimeout = None) -> None:
-        self._http = Network(api_key, api_kind, network, loop, timeout)
+                 loop: AbstractEventLoop = None, timeout: ClientTimeout = None, proxy: str = None) -> None:
+        self._http = Network(api_key, api_kind, network, loop, timeout, proxy)
 
         self.account = Account(self)
         self.block = Block(self)
@@ -26,7 +26,7 @@ class Client:
         self.logs = Logs(self)
         self.proxy = Proxy(self)
 
-        self.utils = Utils(self)
+        self.utils = Utils(self, self._http.BASE_URL)
 
     async def close(self):
         await self._http.close()
