@@ -170,22 +170,6 @@ async def test_close_session(nw: Network):
         nw._session.close.assert_called_once()
 
 
-# @pytest.mark.parametrize(
-#     "api_kind, network_name, expected", [
-#         ('eth', 'main', 'https://api.etherscan.io/api'),
-#         ('eth', 'kovan', 'https://api-kovan.etherscan.io/api'),
-#         ('bsc', 'main', 'https://api.bscscan.com/api'),
-#         ('bsc', 'testnet', 'https://api-testnet.bscscan.com/api'),
-#         ('avax', 'main', 'https://api.snowtrace.io/api'),
-#         ('avax', 'testnet', 'https://api-testnet.snowtrace.io/api'),
-#         ('polygon', 'main', 'https://api.polygonscan.com/api'),
-#         ('polygon', 'testnet', 'https://api-testnet.polygonscan.com/api'),
-#         ('optimism', 'main', 'https://api-optimistic.etherscan.io/api'),
-#         ('optimism', 'testnet', 'https://api-testnet-optimistic.etherscan.io/api'),
-#         ('arbitrum', 'main', 'https://api.arbiscan.io/api'),
-#         ('arbitrum', 'testnet', 'https://api-testnet.arbiscan.io/api'),
-#     ]
-# )
 @pytest.mark.parametrize(
     "api_kind,network_name,expected",
     [
@@ -206,6 +190,8 @@ async def test_close_session(nw: Network):
         ('arbitrum', 'main', 'https://api.arbiscan.io/api'),
         ('arbitrum', 'nova', 'https://api-nova.arbiscan.io/api'),
         ('arbitrum', 'goerli', 'https://api-goerli.arbiscan.io/api'),
+        ('fantom', 'main', 'https://api.ftmscan.com/api'),
+        ('fantom', 'testnet', 'https://api-testnet.ftmscan.com/api'),
     ]
 )
 def test_test_network(api_kind, network_name, expected):
@@ -216,4 +202,4 @@ def test_test_network(api_kind, network_name, expected):
 def test_invalid_api_kind():
     with pytest.raises(ValueError) as excinfo:
         Network(apikey(), 'wrong', 'main', get_loop())
-    assert 'Incorrect api_kind' in str(excinfo.value)
\ No newline at end of file
+    assert 'Incorrect api_kind' in str(excinfo.value)
